@@ -3,7 +3,7 @@ use strict;
 use DBI;
 
 use vars qw($VERSION);
-$VERSION = '0.09';
+$VERSION = '0.10';
 
 =head1 NAME
 
@@ -231,7 +231,7 @@ sub parse_command_line {
 sub handle_command_line {
     my ($package,$appname,@argv) =  @_;
     
-    my $opts = $package->parse_command_line(@argv)
+    my $opts = $package->parse_command_line($appname,@argv)
         or pod2usage(2);
     pod2usage(1) if $opts->{help};
     pod2usage(-verbose => 2) if $opts->{man};
